==> lxqt-panel-0.9.0.tar.xz: lxqt-panel-0.9.0/plugin-networkmonitor/translations/networkmonitor_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>LxQtNetworkMonitor</name>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="161"/>
        <source>Network interface &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Мережевий адаптер &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="162"/>
        <source>Transmitted %1</source>
        <translation>Передано %1</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="163"/>
        <source>Received %1</source>
        <translation>Прийнято %1</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="208"/>
        <source>B</source>
        <translation>Б</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>KiB</source>
        <translation>КіБ</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>MiB</source>
        <translation>МіБ</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>GiB</source>
        <translation>ГіБ</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>TiB</source>
        <translation>ТіБ</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>PiB</source>
        <translation>ПіБ</translation>
    </message>
</context>
<context>
    <name>LxQtNetworkMonitorConfiguration</name>
    <message>
        <source>LxQt Network Monitor settings</source>
        <translation type="vanished">Налаштування монітору мережі LxQt</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="14"/>
        <source>Network Monitor settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Загальне</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="35"/>
        <source>Interface</source>
        <translation>Адаптер</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="56"/>
        <source>Modem</source>
        <translation>Модем</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="65"/>
        <source>Monitor</source>
        <translation>Монітор</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="74"/>
        <source>Network</source>
        <translation>Мережевий</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="83"/>
        <source>Wireless</source>
        <translation>Бездротовий</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="95"/>
        <source>Icon</source>
        <translation>Значок</translation>
    </message>
</context>
</TS>

==> lxqt-panel-0.14.0.tar.xz: lxqt-panel-0.14.0/plugin-networkmonitor/translations/networkmonitor_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>LXQtNetworkMonitor</name>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="161"/>
        <source>Network interface &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Мережевий адаптер &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="162"/>
        <source>Transmitted %1</source>
        <translation>Передано %1</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="163"/>
        <source>Received %1</source>
        <translation>Прийнято %1</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="208"/>
        <source>B</source>
        <translation>Б</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>KiB</source>
        <translation>КіБ</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>MiB</source>
        <translation>МіБ</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>GiB</source>
        <translation>ГіБ</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>TiB</source>
        <translation>ТіБ</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>PiB</source>
        <translation>ПіБ</translation>
    </message>
</context>
<context>
    <name>LXQtNetworkMonitorConfiguration</name>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="14"/>
        <source>Network Monitor settings</source>
        <translation>Налаштуванян монітору мережі</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Загальне</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="35"/>
        <source>Interface</source>
        <translation>Адаптер</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="56"/>
        <source>Modem</source>
        <translation>Модем</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="65"/>
        <source>Monitor</source>
        <translation>Монітор</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="74"/>
        <source>Network</source>
        <translation>Мережевий</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="83"/>
        <source>Wireless</source>
        <translation>Бездротовий</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="95"/>
        <source>Icon</source>
        <translation>Значок</translation>
    </message>
</context>
</TS>
